@@ -128,10 +128,10 @@ class BuilderInterface(object):
 
             # Make sure reserved fields are set
             build_data.setdefault('artifacts', [])
-            build_data.setdefault('force-include', {})
+            build_data.setdefault('force_include', {})
 
-            # Pass all the configured build hooks for future unforeseen scenarios needing ultimate control
-            build_data['configured_build_hooks'] = configured_build_hooks
+            # Allow inspection of configured build hooks and the order in which they run
+            build_data['build_hooks'] = tuple(configured_build_hooks)
 
             # Execute all `initialize` build hooks
             for build_hook in build_hooks:
@@ -167,7 +167,7 @@ class BuilderInterface(object):
         for project_file in self.recurse_project_files():
             yield project_file
 
-        for explicit_file in self.recurse_explicit_files(self.config.get_force_include()):
+        for explicit_file in self.recurse_explicit_files():
             yield explicit_file
 
     def recurse_project_files(self):
@@ -178,14 +178,17 @@ class BuilderInterface(object):
             if relative_path == '.':
                 relative_path = ''
 
-            dirs[:] = sorted(
-                d
-                for d in dirs
-                # The trailing slash is necessary so e.g. `bar/` matches `foo/bar`
-                if not self.config.path_is_excluded('{}/'.format(os.path.join(relative_path, d)))
-            )
+            if self.config.skip_excluded_dirs:
+                dirs[:] = sorted(
+                    d
+                    for d in dirs
+                    # The trailing slash is necessary so e.g. `bar/` matches `foo/bar`
+                    if not self.config.path_is_excluded('{}/'.format(os.path.join(relative_path, d)))
+                )
+            else:
+                dirs.sort()
 
-            files = sorted(files)
+            files.sort()
             is_package = '__init__.py' in files
             for f in files:
                 relative_file_path = os.path.join(relative_path, f)
@@ -194,7 +197,10 @@ class BuilderInterface(object):
                         os.path.join(root, f), relative_file_path, self.config.get_distribution_path(relative_file_path)
                     )
 
-    def recurse_explicit_files(self, inclusion_map):
+    def recurse_explicit_files(self, inclusion_map=None):
+        if inclusion_map is None:
+            inclusion_map = self.config.get_force_include()
+
         for source, target_path in inclusion_map.items():
             external = not source.startswith(self.root)
             if os.path.isfile(source):
